@@ -560,7 +560,7 @@ transmit_item (void *cls,
  * Handle RESERVE-message.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static void
 handle_reserve (void *cls, const struct ReserveMessage *msg)
@@ -599,7 +599,8 @@ handle_reserve (void *cls, const struct ReserveMessage *msg)
        * message happens, the insertion request could be blocked
        * by less-important content from migration because it is
        * larger than 1/8th of the overall available space, and
-       * we only reserve 1/8th for "fresh" insertions */GNUNET_log (
+       * we only reserve 1/8th for "fresh" insertions */
+      GNUNET_log (
         GNUNET_ERROR_TYPE_WARNING,
         _ (
           "The requested amount (%llu bytes) is larger than the cache size (%llu bytes)\n"),
@@ -643,7 +644,7 @@ handle_reserve (void *cls, const struct ReserveMessage *msg)
  * Handle RELEASE_RESERVE-message.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static void
 handle_release_reserve (void *cls, const struct ReleaseReserveMessage *msg)
@@ -767,7 +768,7 @@ put_continuation (void *cls,
  * Verify PUT-message.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param dm the actual message
  * @return #GNUNET_OK if @a dm is well-formed
  */
 static int
@@ -786,7 +787,7 @@ check_put (void *cls, const struct DataMessage *dm)
  * Handle PUT-message.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param dm the actual message
  */
 static void
 handle_put (void *cls, const struct DataMessage *dm)
@@ -948,7 +949,7 @@ handle_get_replication (void *cls, const struct GNUNET_MessageHeader *message)
  * Handle GET_ZERO_ANONYMITY-message.
  *
  * @param cls client identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static void
 handle_get_zero_anonymity (void *cls, const struct GetZeroAnonymityMessage *msg)
@@ -1027,7 +1028,7 @@ remove_continuation (void *cls,
  * Verify REMOVE-message.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param dm the actual message
  * @return #GNUNET_OK if @a dm is well-formed
  */
 static int
@@ -1046,8 +1047,7 @@ check_remove (void *cls, const struct DataMessage *dm)
  * Handle REMOVE-message.
  *
  * @param cls closure
- * @param client identification of the client
- * @param message the actual message
+ * @param dm the actual message
  */
 static void
 handle_remove (void *cls, const struct DataMessage *dm)
