@@ -565,15 +565,6 @@ consider_peer_for_forwarding (void *cls,
 }
 
 
-/**
- * A peer connected to us.  Setup the connected peer
- * records.
- *
- * @param cls NULL
- * @param peer identity of peer that connected
- * @param mq message queue for talking to @a peer
- * @return our internal handle for the peer
- */
 void *
 GSF_peer_connect_handler (void *cls,
                           const struct GNUNET_PeerIdentity *peer,
@@ -648,12 +639,6 @@ revive_migration (void *cls)
 }
 
 
-/**
- * Get a handle for a connected peer.
- *
- * @param peer peer's identity
- * @return NULL if the peer is not currently connected
- */
 struct GSF_ConnectedPeer *
 GSF_peer_get_ (const struct GNUNET_PeerIdentity *peer)
 {
@@ -836,7 +821,7 @@ get_randomized_delay ()
  */
 static void
 handle_p2p_reply (void *cls,
-                  enum GNUNET_BLOCK_EvaluationResult eval,
+                  enum GNUNET_BLOCK_ReplyEvaluationResult eval,
                   struct GSF_PendingRequest *pr,
                   uint32_t reply_anonymity_level,
                   struct GNUNET_TIME_Absolute expiration,
@@ -862,11 +847,11 @@ handle_p2p_reply (void *cls,
     return;
   }
   GNUNET_break (GNUNET_BLOCK_TYPE_ANY != type);
-  if ((prd->type != type) && (GNUNET_BLOCK_TYPE_ANY != prd->type))
+  if ( (prd->type != type) &&
+       (GNUNET_BLOCK_TYPE_ANY != prd->type) )
   {
     GNUNET_STATISTICS_update (GSF_stats,
-                              gettext_noop
-                                ("# replies dropped due to type mismatch"),
+                              "# replies dropped due to type mismatch",
                               1, GNUNET_NO);
     return;
   }
@@ -874,22 +859,22 @@ handle_p2p_reply (void *cls,
               "Transmitting result for query `%s' to peer\n",
               GNUNET_h2s (&prd->query));
   GNUNET_STATISTICS_update (GSF_stats,
-                            gettext_noop ("# replies received for other peers"),
-                            1, GNUNET_NO);
+                            "# replies received for other peers",
+                            1,
+                            GNUNET_NO);
   msize = sizeof(struct PutMessage) + data_len;
   if (msize >= GNUNET_MAX_MESSAGE_SIZE)
   {
     GNUNET_break (0);
     return;
   }
-  if ((UINT32_MAX != reply_anonymity_level) && (reply_anonymity_level > 1))
+  if ( (UINT32_MAX != reply_anonymity_level) &&
+       (reply_anonymity_level > 1) )
   {
     if (reply_anonymity_level - 1 > GSF_cover_content_count)
     {
       GNUNET_STATISTICS_update (GSF_stats,
-                                gettext_noop
-                                (
-                                  "# replies dropped due to insufficient cover traffic"),
+                                "# replies dropped due to insufficient cover traffic",
                                 1, GNUNET_NO);
       return;
     }
@@ -930,14 +915,12 @@ handle_p2p_reply (void *cls,
                         UINT32_MAX,
                         env);
   }
-  if (GNUNET_BLOCK_EVALUATION_OK_LAST != eval)
+  if (GNUNET_BLOCK_REPLY_OK_LAST != eval)
     return;
   if (NULL == peerreq->kill_task)
   {
     GNUNET_STATISTICS_update (GSF_stats,
-                              gettext_noop
-                              (
-                                "# P2P searches destroyed due to ultimate reply"),
+                              "# P2P searches destroyed due to ultimate reply",
                               1,
                               GNUNET_NO);
     peerreq->kill_task =
@@ -1319,7 +1302,6 @@ handle_p2p_get (void *cls,
                                     ? (const char *) &opt[bits]
                                     : NULL,
                                     bfsize,
-                                    ntohl (gm->filter_mutator),
                                     1 /* anonymity */,
                                     (uint32_t) tec.priority,
                                     tec.ttl,
@@ -1360,8 +1342,6 @@ handle_p2p_get (void *cls,
  * @param cp target peer
  * @param is_query is this a query (#GNUNET_YES) or content (#GNUNET_NO) or neither (#GNUNET_SYSERR)
  * @param priority how important is this request?
- * @param timeout when does this request timeout
- * @param size number of bytes we would like to send to the peer
  * @param env message to send
  */
 void
@@ -1491,14 +1471,6 @@ flush_respect (void *cls,
 }
 
 
-/**
- * A peer disconnected from us.  Tear down the connected peer
- * record.
- *
- * @param cls unused
- * @param peer identity of peer that disconnected
- * @param internal_cls the corresponding `struct GSF_ConnectedPeer`
- */
 void
 GSF_peer_disconnect_handler (void *cls,
                              const struct GNUNET_PeerIdentity *peer,
@@ -1623,12 +1595,6 @@ call_iterator (void *cls,
 }
 
 
-/**
- * Iterate over all connected peers.
- *
- * @param it function to call for each peer
- * @param it_cls closure for @a it
- */
 void
 GSF_iterate_connected_peers_ (GSF_ConnectedPeerIterator it,
                               void *it_cls)
