@@ -26,6 +26,7 @@
 #include "platform.h"
 #include "gnunet_util_lib.h"
 #include "gnunet_constants.h"
+#include "gnunet_error_codes.h"
 #include "gnunet_protocols.h"
 #include "gnunet_identity_service.h"
 #include "identity.h"
@@ -157,14 +158,17 @@ GNUNET_IDENTITY_ego_get_anonymous ()
 {
   static struct GNUNET_IDENTITY_Ego anon;
   static int setup;
+  ssize_t key_len;
 
   if (setup)
     return &anon;
   anon.pk.type = htonl (GNUNET_IDENTITY_TYPE_ECDSA);
   anon.pub.type = htonl (GNUNET_IDENTITY_TYPE_ECDSA);
   anon.pk.ecdsa_key = *GNUNET_CRYPTO_ecdsa_key_get_anonymous ();
+  key_len = GNUNET_IDENTITY_private_key_get_length (&anon.pk);
+  GNUNET_assert (0 < key_len);
   GNUNET_CRYPTO_hash (&anon.pk,
-                      sizeof(anon.pk),
+                      key_len,
                       &anon.id);
   setup = 1;
   return &anon;
@@ -195,7 +199,7 @@ GNUNET_IDENTITY_key_get_public (const struct
 }
 
 
-static int
+static enum GNUNET_GenericReturnValue
 private_key_create (enum GNUNET_IDENTITY_KeyType ktype,
                     struct GNUNET_IDENTITY_PrivateKey *key)
 {
@@ -279,13 +283,13 @@ reschedule_connect (struct GNUNET_IDENTITY_Handle *h)
                                  op);
     if (NULL != op->cont)
       op->cont (op->cls,
-                "Error in communication with the identity service");
+                GNUNET_EC_SERVICE_COMMUNICATION_FAILED);
     else if (NULL != op->cb)
       op->cb (op->cls, NULL, NULL, NULL);
     else if (NULL != op->create_cont)
       op->create_cont (op->cls,
                        NULL,
-                       "Failed to communicate with the identity service");
+                       GNUNET_EC_SERVICE_COMMUNICATION_FAILED);
     GNUNET_free (op);
   }
   GNUNET_CONTAINER_multihashmap_iterate (h->egos,
@@ -321,24 +325,6 @@ mq_error_handler (void *cls,
 }
 
 
-/**
- * We received a result code from the service.  Check the message
- * is well-formed.
- *
- * @param cls closure
- * @param rcm result message received
- * @return #GNUNET_OK if the message is well-formed
- */
-static int
-check_identity_result_code (void *cls,
-                            const struct ResultCodeMessage *rcm)
-{
-  if (sizeof(*rcm) != htons (rcm->header.size))
-    GNUNET_MQ_check_zero_termination (rcm);
-  return GNUNET_OK;
-}
-
-
 /**
  * We received a result code from the service.
  *
@@ -351,8 +337,7 @@ handle_identity_result_code (void *cls,
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   struct GNUNET_IDENTITY_Operation *op;
-  uint16_t size = ntohs (rcm->header.size) - sizeof(*rcm);
-  const char *str = (0 == size) ? NULL : (const char *) &rcm[1];
+  enum GNUNET_ErrorCode ec = ntohl (rcm->result_code);
 
   op = h->op_head;
   if (NULL == op)
@@ -363,11 +348,11 @@ handle_identity_result_code (void *cls,
   }
   GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
   if (NULL != op->cont)
-    op->cont (op->cls, str);
+    op->cont (op->cls, ec);
   else if (NULL != op->cb)
     op->cb (op->cls, NULL, NULL, NULL);
   else if (NULL != op->create_cont)
-    op->create_cont (op->cls, (NULL == str) ? &op->pk : NULL, str);
+    op->create_cont (op->cls, (GNUNET_EC_NONE == ec) ? &op->pk : NULL, ec);
   GNUNET_free (op);
 }
 
@@ -387,7 +372,7 @@ check_identity_update (void *cls,
   uint16_t name_len = ntohs (um->name_len);
   const char *str = (const char *) &um[1];
 
-  if ((size != name_len + sizeof(struct UpdateMessage)) ||
+  if ((size < name_len + sizeof(struct UpdateMessage)) ||
       ((0 != name_len) && ('\0' != str[name_len - 1])))
   {
     GNUNET_break (0);
@@ -409,9 +394,13 @@ handle_identity_update (void *cls,
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   uint16_t name_len = ntohs (um->name_len);
-  const char *str = (0 == name_len) ? NULL : (const char *) &um[1];
+  const char *str;
+  size_t key_len;
+  size_t kb_read;
   struct GNUNET_HashCode id;
   struct GNUNET_IDENTITY_Ego *ego;
+  struct GNUNET_IDENTITY_PrivateKey private_key;
+  const char *tmp;
 
   if (GNUNET_YES == ntohs (um->end_of_list))
   {
@@ -420,8 +409,18 @@ handle_identity_update (void *cls,
       h->cb (h->cb_cls, NULL, NULL, NULL);
     return;
   }
-  GNUNET_CRYPTO_hash (&um->private_key,
-                      sizeof (um->private_key),
+  tmp = (const char*) &um[1];
+  str = (0 == name_len) ? NULL : tmp;
+  memset (&private_key, 0, sizeof (private_key));
+  key_len = ntohs (um->key_len);
+  GNUNET_assert (GNUNET_SYSERR !=
+                 GNUNET_IDENTITY_read_private_key_from_buffer (tmp + name_len,
+                                                               key_len,
+                                                               &private_key,
+                                                               &kb_read));
+  GNUNET_assert (0 <= GNUNET_IDENTITY_private_key_get_length (&private_key));
+  GNUNET_CRYPTO_hash (&private_key,
+                      GNUNET_IDENTITY_private_key_get_length (&private_key),
                       &id);
   ego = GNUNET_CONTAINER_multihashmap_get (h->egos,
                                            &id);
@@ -437,7 +436,7 @@ handle_identity_update (void *cls,
     }
     ego = GNUNET_new (struct GNUNET_IDENTITY_Ego);
     ego->pub_initialized = GNUNET_NO;
-    ego->pk = um->private_key;
+    ego->pk = private_key;
     ego->name = GNUNET_strdup (str);
     ego->id = id;
     GNUNET_assert (GNUNET_YES ==
@@ -476,80 +475,6 @@ handle_identity_update (void *cls,
 }
 
 
-/**
- * Function called when we receive a set default message from the
- * service.
- *
- * @param cls closure
- * @param sdm message received
- * @return #GNUNET_OK if the message is well-formed
- */
-static int
-check_identity_set_default (void *cls,
-                            const struct SetDefaultMessage *sdm)
-{
-  uint16_t size = ntohs (sdm->header.size) - sizeof(*sdm);
-  uint16_t name_len = ntohs (sdm->name_len);
-  const char *str = (const char *) &sdm[1];
-
-  if ((size != name_len) || ((0 != name_len) && ('\0' != str[name_len - 1])))
-  {
-    GNUNET_break (0);
-    return GNUNET_SYSERR;
-  }
-  GNUNET_break (0 == ntohs (sdm->reserved));
-  return GNUNET_OK;
-}
-
-
-/**
- * Type of a function to call when we receive a message
- * from the service.
- *
- * @param cls closure
- * @param sdm message received
- */
-static void
-handle_identity_set_default (void *cls,
-                             const struct SetDefaultMessage *sdm)
-{
-  struct GNUNET_IDENTITY_Handle *h = cls;
-  struct GNUNET_IDENTITY_Operation *op;
-  struct GNUNET_HashCode id;
-  struct GNUNET_IDENTITY_Ego *ego;
-
-  GNUNET_CRYPTO_hash (&sdm->private_key,
-                      sizeof(sdm->private_key),
-                      &id);
-  ego = GNUNET_CONTAINER_multihashmap_get (h->egos,
-                                           &id);
-  if (NULL == ego)
-  {
-    GNUNET_break (0);
-    reschedule_connect (h);
-    return;
-  }
-  op = h->op_head;
-  if (NULL == op)
-  {
-    GNUNET_break (0);
-    reschedule_connect (h);
-    return;
-  }
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Received SET_DEFAULT message from identity service\n");
-  GNUNET_CONTAINER_DLL_remove (h->op_head,
-                               h->op_tail,
-                               op);
-  if (NULL != op->cb)
-    op->cb (op->cls,
-            ego,
-            &ego->ctx,
-            ego->name);
-  GNUNET_free (op);
-}
-
-
 /**
  * Try again to connect to the identity service.
  *
@@ -560,18 +485,14 @@ reconnect (void *cls)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   struct GNUNET_MQ_MessageHandler handlers[] = {
-    GNUNET_MQ_hd_var_size (identity_result_code,
-                           GNUNET_MESSAGE_TYPE_IDENTITY_RESULT_CODE,
-                           struct ResultCodeMessage,
-                           h),
+    GNUNET_MQ_hd_fixed_size (identity_result_code,
+                             GNUNET_MESSAGE_TYPE_IDENTITY_RESULT_CODE,
+                             struct ResultCodeMessage,
+                             h),
     GNUNET_MQ_hd_var_size (identity_update,
                            GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE,
                            struct UpdateMessage,
                            h),
-    GNUNET_MQ_hd_var_size (identity_set_default,
-                           GNUNET_MESSAGE_TYPE_IDENTITY_SET_DEFAULT,
-                           struct SetDefaultMessage,
-                           h),
     GNUNET_MQ_handler_end ()
   };
   struct GNUNET_MQ_Envelope *env;
@@ -661,98 +582,6 @@ GNUNET_IDENTITY_ego_get_public_key (struct GNUNET_IDENTITY_Ego *ego,
 }
 
 
-/**
- * Obtain the identity that is currently preferred/default
- * for a service.
- *
- * @param h identity service to query
- * @param service_name for which service is an identity wanted
- * @param cb function to call with the result (will only be called once)
- * @param cb_cls closure for @a cb
- * @return handle to abort the operation
- */
-struct GNUNET_IDENTITY_Operation *
-GNUNET_IDENTITY_get (struct GNUNET_IDENTITY_Handle *h,
-                     const char *service_name,
-                     GNUNET_IDENTITY_Callback cb,
-                     void *cb_cls)
-{
-  struct GNUNET_IDENTITY_Operation *op;
-  struct GNUNET_MQ_Envelope *env;
-  struct GetDefaultMessage *gdm;
-  size_t slen;
-
-  if (NULL == h->mq)
-    return NULL;
-  GNUNET_assert (NULL != h->cb);
-  slen = strlen (service_name) + 1;
-  if (slen >= GNUNET_MAX_MESSAGE_SIZE - sizeof(struct GetDefaultMessage))
-  {
-    GNUNET_break (0);
-    return NULL;
-  }
-  op = GNUNET_new (struct GNUNET_IDENTITY_Operation);
-  op->h = h;
-  op->cb = cb;
-  op->cls = cb_cls;
-  GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  env =
-    GNUNET_MQ_msg_extra (gdm, slen, GNUNET_MESSAGE_TYPE_IDENTITY_GET_DEFAULT);
-  gdm->name_len = htons (slen);
-  gdm->reserved = htons (0);
-  GNUNET_memcpy (&gdm[1], service_name, slen);
-  GNUNET_MQ_send (h->mq, env);
-  return op;
-}
-
-
-/**
- * Set the preferred/default identity for a service.
- *
- * @param h identity service to inform
- * @param service_name for which service is an identity set
- * @param ego new default identity to be set for this service
- * @param cont function to call once the operation finished
- * @param cont_cls closure for @a cont
- * @return handle to abort the operation
- */
-struct GNUNET_IDENTITY_Operation *
-GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *h,
-                     const char *service_name,
-                     struct GNUNET_IDENTITY_Ego *ego,
-                     GNUNET_IDENTITY_Continuation cont,
-                     void *cont_cls)
-{
-  struct GNUNET_IDENTITY_Operation *op;
-  struct GNUNET_MQ_Envelope *env;
-  struct SetDefaultMessage *sdm;
-  size_t slen;
-
-  if (NULL == h->mq)
-    return NULL;
-  GNUNET_assert (NULL != h->cb);
-  slen = strlen (service_name) + 1;
-  if (slen >= GNUNET_MAX_MESSAGE_SIZE - sizeof(struct SetDefaultMessage))
-  {
-    GNUNET_break (0);
-    return NULL;
-  }
-  op = GNUNET_new (struct GNUNET_IDENTITY_Operation);
-  op->h = h;
-  op->cont = cont;
-  op->cls = cont_cls;
-  GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  env =
-    GNUNET_MQ_msg_extra (sdm, slen, GNUNET_MESSAGE_TYPE_IDENTITY_SET_DEFAULT);
-  sdm->name_len = htons (slen);
-  sdm->reserved = htons (0);
-  sdm->private_key = ego->pk;
-  GNUNET_memcpy (&sdm[1], service_name, slen);
-  GNUNET_MQ_send (h->mq, env);
-  return op;
-}
-
-
 struct GNUNET_IDENTITY_Operation *
 GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *h,
                         const char *name,
@@ -761,10 +590,12 @@ GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *h,
                         GNUNET_IDENTITY_CreateContinuation cont,
                         void *cont_cls)
 {
+  struct GNUNET_IDENTITY_PrivateKey private_key;
   struct GNUNET_IDENTITY_Operation *op;
   struct GNUNET_MQ_Envelope *env;
   struct CreateRequestMessage *crm;
   size_t slen;
+  size_t key_len;
 
   if (NULL == h->mq)
     return NULL;
@@ -779,18 +610,23 @@ GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *h,
   op->create_cont = cont;
   op->cls = cont_cls;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  env = GNUNET_MQ_msg_extra (crm, slen, GNUNET_MESSAGE_TYPE_IDENTITY_CREATE);
-  crm->name_len = htons (slen);
-  crm->reserved = htons (0);
   if (NULL == privkey)
   {
     GNUNET_assert (GNUNET_OK ==
-                   private_key_create (ktype, &crm->private_key));
+                   private_key_create (ktype, &private_key));
   }
   else
-    crm->private_key = *privkey;
-  op->pk = crm->private_key;
-  GNUNET_memcpy (&crm[1], name, slen);
+    private_key = *privkey;
+  key_len = GNUNET_IDENTITY_private_key_get_length (&private_key);
+  env = GNUNET_MQ_msg_extra (crm, slen + key_len,
+                             GNUNET_MESSAGE_TYPE_IDENTITY_CREATE);
+  crm->name_len = htons (slen);
+  GNUNET_IDENTITY_write_private_key_to_buffer (&private_key,
+                                               &crm[1],
+                                               key_len);
+  crm->key_len = htons (key_len);
+  op->pk = private_key;
+  GNUNET_memcpy ((char*) &crm[1] + key_len, name, slen);
   GNUNET_MQ_send (h->mq, env);
   return op;
 }
@@ -969,8 +805,9 @@ check_key_type (uint32_t type)
 }
 
 
-static ssize_t
-private_key_get_length (const struct GNUNET_IDENTITY_PrivateKey *key)
+ssize_t
+GNUNET_IDENTITY_private_key_get_length (const struct
+                                        GNUNET_IDENTITY_PrivateKey *key)
 {
   switch (ntohl (key->type))
   {
@@ -981,6 +818,8 @@ private_key_get_length (const struct GNUNET_IDENTITY_PrivateKey *key)
     return sizeof (key->type) + sizeof (key->eddsa_key);
     break;
   default:
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Got key type %u\n", ntohl (key->type));
     GNUNET_break (0);
   }
   return -1;
@@ -988,7 +827,8 @@ private_key_get_length (const struct GNUNET_IDENTITY_PrivateKey *key)
 
 
 ssize_t
-GNUNET_IDENTITY_key_get_length (const struct GNUNET_IDENTITY_PublicKey *key)
+GNUNET_IDENTITY_public_key_get_length (const struct
+                                       GNUNET_IDENTITY_PublicKey *key)
 {
   switch (ntohl (key->type))
   {
@@ -1004,34 +844,98 @@ GNUNET_IDENTITY_key_get_length (const struct GNUNET_IDENTITY_PublicKey *key)
 
 
 ssize_t
-GNUNET_IDENTITY_read_key_from_buffer (struct GNUNET_IDENTITY_PublicKey *key,
-                                      const void *buffer,
-                                      size_t len)
+GNUNET_IDENTITY_private_key_length_by_type (enum GNUNET_IDENTITY_KeyType kt)
+{
+  switch (kt)
+  {
+  case GNUNET_IDENTITY_TYPE_ECDSA:
+    return sizeof (struct GNUNET_CRYPTO_EcdsaPrivateKey);
+    break;
+  case GNUNET_IDENTITY_TYPE_EDDSA:
+    return sizeof (struct GNUNET_CRYPTO_EcdsaPrivateKey);
+    break;
+  default:
+    GNUNET_break (0);
+  }
+  return -1;
+}
+
+
+enum GNUNET_GenericReturnValue
+GNUNET_IDENTITY_read_public_key_from_buffer (const void *buffer,
+                                             size_t len,
+                                             struct GNUNET_IDENTITY_PublicKey *
+                                             key,
+                                             size_t *kb_read)
 {
   if (len < sizeof (key->type))
-    return -1;
+    return GNUNET_SYSERR;
   GNUNET_memcpy (&key->type,
                  buffer,
                  sizeof (key->type));
-  ssize_t length = GNUNET_IDENTITY_key_get_length (key);
+  ssize_t length = GNUNET_IDENTITY_public_key_get_length (key);
+  if (len < length)
+    return GNUNET_SYSERR;
+  if (length < 0)
+    return GNUNET_SYSERR;
+  GNUNET_memcpy (&key->ecdsa_key,
+                 buffer + sizeof (key->type),
+                 length - sizeof (key->type));
+  *kb_read = length;
+  return GNUNET_OK;
+}
+
+
+ssize_t
+GNUNET_IDENTITY_write_public_key_to_buffer (const struct
+                                            GNUNET_IDENTITY_PublicKey *key,
+                                            void*buffer,
+                                            size_t len)
+{
+  const ssize_t length = GNUNET_IDENTITY_public_key_get_length (key);
   if (len < length)
     return -1;
   if (length < 0)
     return -2;
-  GNUNET_memcpy (&key->ecdsa_key,
-                 buffer + sizeof (key->type),
-                 length - sizeof (key->type));
+  GNUNET_memcpy (buffer, &(key->type), sizeof (key->type));
+  GNUNET_memcpy (buffer + sizeof (key->type), &(key->ecdsa_key), length
+                 - sizeof (key->type));
   return length;
 }
 
 
-ssize_t
-GNUNET_IDENTITY_write_key_to_buffer (const struct
-                                     GNUNET_IDENTITY_PublicKey *key,
-                                     void*buffer,
-                                     size_t len)
+enum GNUNET_GenericReturnValue
+GNUNET_IDENTITY_read_private_key_from_buffer (const void *buffer,
+                                              size_t len,
+                                              struct
+                                              GNUNET_IDENTITY_PrivateKey *key,
+                                              size_t *kb_read)
 {
-  const ssize_t length = GNUNET_IDENTITY_key_get_length (key);
+  if (len < sizeof (key->type))
+    return GNUNET_SYSERR;
+  GNUNET_memcpy (&key->type,
+                 buffer,
+                 sizeof (key->type));
+  ssize_t length = GNUNET_IDENTITY_private_key_get_length (key);
+  if (len < length)
+    return GNUNET_SYSERR;
+  if (length < 0)
+    return GNUNET_SYSERR;
+  GNUNET_memcpy (&key->ecdsa_key,
+                 buffer + sizeof (key->type),
+                 length - sizeof (key->type));
+  *kb_read = length;
+  return GNUNET_OK;
+}
+
+
+ssize_t
+GNUNET_IDENTITY_write_private_key_to_buffer (const struct
+                                             GNUNET_IDENTITY_PrivateKey *key,
+                                             void *buffer,
+                                             size_t len)
+{
+  const ssize_t length = GNUNET_IDENTITY_private_key_get_length (key);
   if (len < length)
     return -1;
   if (length < 0)
@@ -1080,7 +984,6 @@ GNUNET_IDENTITY_signature_get_raw_length_by_type (uint32_t type)
 }
 
 
-
 ssize_t
 GNUNET_IDENTITY_read_signature_from_buffer (struct
                                             GNUNET_IDENTITY_Signature *sig,
@@ -1118,6 +1021,7 @@ GNUNET_IDENTITY_write_signature_to_buffer (const struct
   return length;
 }
 
+
 enum GNUNET_GenericReturnValue
 GNUNET_IDENTITY_sign_raw_ (const struct
                            GNUNET_IDENTITY_PrivateKey *priv,
@@ -1129,11 +1033,13 @@ GNUNET_IDENTITY_sign_raw_ (const struct
   {
   case GNUNET_IDENTITY_TYPE_ECDSA:
     return GNUNET_CRYPTO_ecdsa_sign_ (&(priv->ecdsa_key), purpose,
-                                      (struct GNUNET_CRYPTO_EcdsaSignature*)sig);
+                                      (struct
+                                       GNUNET_CRYPTO_EcdsaSignature*) sig);
     break;
   case GNUNET_IDENTITY_TYPE_EDDSA:
     return GNUNET_CRYPTO_eddsa_sign_ (&(priv->eddsa_key), purpose,
-                                      (struct GNUNET_CRYPTO_EddsaSignature*)sig);
+                                      (struct
+                                       GNUNET_CRYPTO_EddsaSignature*) sig);
     break;
   default:
     GNUNET_break (0);
@@ -1143,7 +1049,6 @@ GNUNET_IDENTITY_sign_raw_ (const struct
 }
 
 
-
 enum GNUNET_GenericReturnValue
 GNUNET_IDENTITY_sign_ (const struct
                        GNUNET_IDENTITY_PrivateKey *priv,
@@ -1212,12 +1117,14 @@ GNUNET_IDENTITY_signature_verify_raw_ (uint32_t purpose,
   {
   case GNUNET_IDENTITY_TYPE_ECDSA:
     return GNUNET_CRYPTO_ecdsa_verify_ (purpose, validate,
-                                        (struct GNUNET_CRYPTO_EcdsaSignature*)sig,
+                                        (struct
+                                         GNUNET_CRYPTO_EcdsaSignature*) sig,
                                         &(pub->ecdsa_key));
     break;
   case GNUNET_IDENTITY_TYPE_EDDSA:
     return GNUNET_CRYPTO_eddsa_verify_ (purpose, validate,
-                                        (struct GNUNET_CRYPTO_EddsaSignature*)sig,
+                                        (struct
+                                         GNUNET_CRYPTO_EddsaSignature*) sig,
                                         &(pub->eddsa_key));
     break;
   default:
@@ -1228,8 +1135,6 @@ GNUNET_IDENTITY_signature_verify_raw_ (uint32_t purpose,
 }
 
 
-
-
 ssize_t
 GNUNET_IDENTITY_encrypt (const void *block,
                          size_t size,
@@ -1308,7 +1213,7 @@ char *
 GNUNET_IDENTITY_public_key_to_string (const struct
                                       GNUNET_IDENTITY_PublicKey *key)
 {
-  size_t size = GNUNET_IDENTITY_key_get_length (key);
+  size_t size = GNUNET_IDENTITY_public_key_get_length (key);
   return GNUNET_STRINGS_data_to_string_alloc (key,
                                               size);
 }
@@ -1318,11 +1223,12 @@ char *
 GNUNET_IDENTITY_private_key_to_string (const struct
                                        GNUNET_IDENTITY_PrivateKey *key)
 {
-  size_t size = private_key_get_length (key);
+  size_t size = GNUNET_IDENTITY_private_key_get_length (key);
   return GNUNET_STRINGS_data_to_string_alloc (key,
                                               size);
 }
 
+
 enum GNUNET_GenericReturnValue
 GNUNET_IDENTITY_public_key_from_string (const char *str,
                                         struct GNUNET_IDENTITY_PublicKey *key)
