@@ -26,6 +26,7 @@
  * Generic TCP code for reliable, record-oriented TCP
  * connections between clients and service providers.
  */
+
 #include "platform.h"
 #include "gnunet_protocols.h"
 #include "gnunet_util_lib.h"
@@ -261,8 +262,9 @@ transmit_ready (void *cls)
   len = ntohs (cstate->msg->size);
   GNUNET_assert (cstate->msg_off < len);
   LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "message of type %u trying to send with socket %p (MQ: %p\n",
+       "message of type %u and size %u trying to send with socket %p (MQ: %p\n",
        ntohs (cstate->msg->type),
+       ntohs (cstate->msg->size),
        cstate->sock,
        cstate->mq);
 
@@ -311,8 +313,9 @@ RETRY:
     return;
   }
   LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "sending message of type %u successful\n",
-       ntohs (cstate->msg->type));
+       "sending message of type %u and size %u successful\n",
+       ntohs (cstate->msg->type),
+       ntohs (cstate->msg->size));
   cstate->msg = NULL;
   GNUNET_MQ_impl_send_continue (cstate->mq);
 }
@@ -328,7 +331,7 @@ RETRY:
  *     #GNUNET_NO to stop further processing due to disconnect (no error)
  *     #GNUNET_SYSERR to stop further processing due to error
  */
-static int
+static enum GNUNET_GenericReturnValue
 recv_message (void *cls,
               const struct GNUNET_MessageHeader *msg)
 {
@@ -437,7 +440,7 @@ static void
 receive_ready (void *cls)
 {
   struct ClientState *cstate = cls;
-  int ret;
+  enum GNUNET_GenericReturnValue ret;
 
   cstate->recv_task = NULL;
   cstate->in_destroy = GNUNET_SYSERR;
@@ -462,6 +465,7 @@ receive_ready (void *cls)
     return;
   }
   cstate->in_destroy = GNUNET_NO;
+  GNUNET_assert (NULL == cstate->recv_task);
   cstate->recv_task
     = GNUNET_SCHEDULER_add_read_net (GNUNET_TIME_UNIT_FOREVER_REL,
                                      cstate->sock,
@@ -983,9 +987,9 @@ GNUNET_CLIENT_test (const struct GNUNET_CONFIGURATION_Handle *cfg,
 #if HAVE_SOCKADDR_IN_SUN_LEN
     v4.sin_len = (u_char) sizeof(struct sockaddr_in);
 #endif
-    inet_pton (AF_INET,
-               "127.0.0.1",
-               &v4.sin_addr);
+    GNUNET_assert (1 == inet_pton (AF_INET,
+                                   "127.0.0.1",
+                                   &v4.sin_addr));
     ret = GNUNET_NO;
     sock = socket (AF_INET,
                    SOCK_STREAM,
@@ -1049,17 +1053,6 @@ GNUNET_CLIENT_test (const struct GNUNET_CONFIGURATION_Handle *cfg,
 }
 
 
-/**
- * Create a message queue to connect to a GNUnet service.
- * If handlers are specified, receive messages from the connection.
- *
- * @param cfg our configuration
- * @param service_name name of the service to connect to
- * @param handlers handlers for receiving messages, can be NULL
- * @param error_handler error handler
- * @param error_handler_cls closure for the @a error_handler
- * @return the message queue, NULL on error
- */
 struct GNUNET_MQ_Handle *
 GNUNET_CLIENT_connect (const struct GNUNET_CONFIGURATION_Handle *cfg,
                        const char *service_name,
