@@ -24,8 +24,8 @@
  * @author Nils Durner
  * @author Christian Grothoff
  */
+
 #include "platform.h"
-#include "gnunet_util_lib.h"
 #include "disk.h"
 
 #define LOG(kind, ...) GNUNET_log_from (kind, "util-network", __VA_ARGS__)
@@ -75,13 +75,7 @@ struct GNUNET_NETWORK_Handle
 };
 
 
-/**
- * Test if the given protocol family is supported by this system.
- *
- * @param pf protocol family to test (PF_INET, PF_INET6, PF_UNIX)
- * @return #GNUNET_OK if the PF is supported
- */
-int
+enum GNUNET_GenericReturnValue
 GNUNET_NETWORK_test_pf (int pf)
 {
   static int cache_v4 = -1;
@@ -145,15 +139,6 @@ GNUNET_NETWORK_test_pf (int pf)
 }
 
 
-/**
- * Given a unixpath that is too long (larger than UNIX_PATH_MAX),
- * shorten it to an acceptable length while keeping it unique
- * and making sure it remains a valid filename (if possible).
- *
- * @param unixpath long path, will be freed (or same pointer returned
- *        with moved 0-termination).
- * @return shortened unixpath, NULL on error
- */
 char *
 GNUNET_NETWORK_shorten_unixpath (char *unixpath)
 {
@@ -189,15 +174,6 @@ GNUNET_NETWORK_shorten_unixpath (char *unixpath)
 }
 
 
-/**
- * If services crash, they can leave a unix domain socket file on the
- * disk. This needs to be manually removed, because otherwise both
- * bind() and connect() for the respective address will fail.  In this
- * function, we test if such a left-over file exists, and if so,
- * remove it (unless there is a listening service at the address).
- *
- * @param un unix domain socket address to check
- */
 void
 GNUNET_NETWORK_unix_precheck (const struct sockaddr_un *un)
 {
@@ -244,14 +220,7 @@ GNUNET_NETWORK_unix_precheck (const struct sockaddr_un *un)
 #endif
 
 
-/**
- * Set if a socket should use blocking or non-blocking IO.
- *
- * @param fd socket
- * @param doBlock blocking mode
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
- */
-int
+enum GNUNET_GenericReturnValue
 GNUNET_NETWORK_socket_set_blocking (struct GNUNET_NETWORK_Handle *fd,
                                     int doBlock)
 {
@@ -381,7 +350,8 @@ initialize_network_handle (struct GNUNET_NETWORK_Handle *h,
 
   if (h->fd >= FD_SETSIZE)
   {
-    GNUNET_break (GNUNET_OK == GNUNET_NETWORK_socket_close (h));
+    GNUNET_break (GNUNET_OK ==
+                  GNUNET_NETWORK_socket_close (h));
     errno = EMFILE;
     return GNUNET_SYSERR;
   }
@@ -418,14 +388,6 @@ initialize_network_handle (struct GNUNET_NETWORK_Handle *h,
 }
 
 
-/**
- * accept a new connection on a socket
- *
- * @param desc bound socket
- * @param address address of the connecting peer, may be NULL
- * @param address_len length of @a address
- * @return client socket
- */
 struct GNUNET_NETWORK_Handle *
 GNUNET_NETWORK_socket_accept (const struct GNUNET_NETWORK_Handle *desc,
                               struct sockaddr *address,
@@ -473,15 +435,7 @@ GNUNET_NETWORK_socket_accept (const struct GNUNET_NETWORK_Handle *desc,
 }
 
 
-/**
- * Bind a socket to a particular address.
- *
- * @param desc socket to bind
- * @param address address to be bound
- * @param address_len length of @a address
- * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
- */
-int
+enum GNUNET_GenericReturnValue
 GNUNET_NETWORK_socket_bind (struct GNUNET_NETWORK_Handle *desc,
                             const struct sockaddr *address,
                             socklen_t address_len)
@@ -550,13 +504,7 @@ GNUNET_NETWORK_socket_bind (struct GNUNET_NETWORK_Handle *desc,
 }
 
 
-/**
- * Close a socket
- *
- * @param desc socket
- * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
- */
-int
+enum GNUNET_GenericReturnValue
 GNUNET_NETWORK_socket_close (struct GNUNET_NETWORK_Handle *desc)
 {
   int ret;
@@ -613,11 +561,6 @@ GNUNET_NETWORK_socket_close (struct GNUNET_NETWORK_Handle *desc)
 }
 
 
-/**
- * Only free memory of a socket, keep the file descriptor untouched.
- *
- * @param desc socket
- */
 void
 GNUNET_NETWORK_socket_free_memory_only_ (struct GNUNET_NETWORK_Handle *desc)
 {
@@ -740,16 +683,6 @@ GNUNET_NETWORK_socket_recvfrom_amount (const struct GNUNET_NETWORK_Handle *desc)
 }
 
 
-/**
- * Read data from a socket (always non-blocking).
- *
- * @param desc socket
- * @param buffer buffer
- * @param length length of @a buffer
- * @param src_addr either the source to recv from, or all zeroes
- *        to be filled in by recvfrom
- * @param addrlen length of the @a src_addr
- */
 ssize_t
 GNUNET_NETWORK_socket_recvfrom (const struct GNUNET_NETWORK_Handle *desc,
                                 void *buffer,
@@ -800,14 +733,6 @@ GNUNET_NETWORK_socket_recv (const struct GNUNET_NETWORK_Handle *desc,
 }
 
 
-/**
- * Send data (always non-blocking).
- *
- * @param desc socket
- * @param buffer data to send
- * @param length size of the @a buffer
- * @return number of bytes sent, #GNUNET_SYSERR on error
- */
 ssize_t
 GNUNET_NETWORK_socket_send (const struct GNUNET_NETWORK_Handle *desc,
                             const void *buffer,
